Allow multiple shells to be enabled.
diff --git a/hush.c b/hush.c
index 1344042..0e619f8 100644
--- a/hush.c
+++ b/hush.c
@@ -112,7 +112,7 @@
 #else
 #define applet_name "hush"
 #include "standalone.h"
-#define shell_main main
+#define hush_main main
 #undef BB_FEATURE_SH_FANCY_PROMPT
 #endif
 
@@ -2562,7 +2562,7 @@
 	tcsetpgrp(shell_terminal, shell_pgrp);
 }
 
-int shell_main(int argc, char **argv)
+int hush_main(int argc, char **argv)
 {
 	int opt;
 	FILE *input;
@@ -2572,8 +2572,8 @@
 	global_argc = argc;
 	global_argv = argv;
 	
 	/* (re?) initialize globals.  Sometimes shell_main() ends up calling
 	 * shell_main(), therefore we cannot rely on the BSS to zero out this 
 	 * stuff.  Reset these to 0 every time. */
 	ifs = NULL;
 	/* map[] is taken care of with call to update_ifs_map() */
@@ -2572,8 +2572,8 @@
 	global_argv = argv;
 	
-	/* (re?) initialize globals.  Sometimes shell_main() ends up calling
-	 * shell_main(), therefore we cannot rely on the BSS to zero out this 
+	/* (re?) initialize globals.  Sometimes hush_main() ends up calling
+	 * hush_main(), therefore we cannot rely on the BSS to zero out this 
 	 * stuff.  Reset these to 0 every time. */
 	ifs = NULL;